pub enum AttributePreference {
Preferred,
Acceptable,
}Expand description
A level of preference for a peer attribute.
Invalid peer attributes are represented as errors.
Outbound peer connections are initiated in the sorted order of this type.
The derived order depends on the order of the variants in the enum. The variants are sorted in the order they are listed.
Variants
Preferred
This peer is more likely to be a valid Zcash network peer.
Correctness
This variant must be declared as the first enum variant,
so that Preferred peers sort before Acceptable peers.
Acceptable
This peer is possibly a valid Zcash network peer.
Implementations
Sourceimpl AttributePreference
impl AttributePreference
Sourcepub fn preferred_from(is_preferred: bool) -> Self
pub fn preferred_from(is_preferred: bool) -> Self
Returns Preferred if is_preferred is true.
Sourcepub fn is_preferred(&self) -> bool
pub fn is_preferred(&self) -> bool
Returns true for Preferred attributes.